# oneNeuron_pypi
oneNeuron_pypi

## How to use this 

```python
from oneNeuron.perceptron import Perceptron

## get x and y and then use this commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)


               
# Reference
[offical python docs](https://packaging.python.org/tutorials/packaging-projects/)

[github docs for github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)